=========
Changelog
=========

Version 0.0.9
=================
* add :code:`get_jsonline_chunk_lazy` and :code:`get_jsonline_chunk`

Version 0.0.8
================
* Make methods available by :code:`import pysenal`

Version 0.0.7
================
* Fix check logic in :code:`index`

Version 0.0.6
================
* Fix bug in :code:`json_serialize`

Version 0.0.5
===============
New Features
----------------

* add :code:`serialize_method` in jsonline write methods
* add :code:`json_serialize` method to help json dumps

Version 0.0.4
===============
New Features
----------------

* add one utils method
    * :code:`index`

Version 0.0.3
===============
New Features
---------------

* Add three utils methods
    * :code:`get_chunk`
    * :code:`list2dict`
    * :code:`get_filenames_in_dir`

Version 0.0.2
==============
New Features
-------------

* Add default parameter in read related methods
* Add more unittests

Version 0.0.1
==============

New Features
-------------

* Add IO related methods and class
